@@ -1,4 +1,7 @@
 import json
+import sys
+import traceback
+from typing import List
 
 from interstate_py.interstate_message import InterstateWireMessage, InterstateWireMessageType
 from interstate_py.multiplex_message import MultiplexMessage
@@ -8,6 +11,7 @@ class ErrorAssembly:
     """
     Converts multiplex messages that contains exceptions to an on_error interstate message carrying the exception
     """
+
     @staticmethod
     def to_on_error(multiplex_message: MultiplexMessage) -> InterstateWireMessage:
         if multiplex_message.type != InterstateWireMessageType.ERROR:
@@ -16,7 +20,7 @@ class ErrorAssembly:
 
         error_type = carried_exception.__class__.__name__
         error_message = ErrorAssembly.exc_message(carried_exception)
-        stacktrace = []
+        stacktrace = ErrorAssembly._get_stacktrace(10)
 
         return InterstateWireMessage(multiplex_message.identity.encode(), InterstateWireMessageType.header("error"),
                                      json.dumps({
@@ -36,4 +40,9 @@ class ErrorAssembly:
         if hasattr(exception, 'message'):
             return exception.message
         else:
-            return repr(exception)
\ No newline at end of file
+            return repr(exception)
+
+    @staticmethod
+    def _get_stacktrace(limit: int) -> List[str]:
+        (_, _, s) = sys.exc_info()
+        return traceback.format_list(traceback.extract_tb(s, limit=limit))
\ No newline at end of file
