@@ -41,7 +41,7 @@ class StreamMultiplexer(AIOWorkerTask):
             await self._raw_outbound_queue.put(message)
         elif multiplex_message.type == InterstateWireMessageType.ERROR:
             self._log.info("[OUT][ERROR] - {}".format(multiplex_message))
-            self._log.warn("Error:", multiplex_message.payload)
+            self._log.warn("[OUT][ERROR] - Propagating error: %s", ErrorAssembly.exc_message(multiplex_message.payload))
             await self._raw_outbound_queue.put(ErrorAssembly.to_on_error(multiplex_message))
             connection.close_outbound()
         elif multiplex_message.type == InterstateWireMessageType.COMPLETE:
